pub type InitialRoomThirdPartyInviteEvent = InitialStateEvent<RoomThirdPartyInviteEventContent>;Available on crate feature
events only.Expand description
An m.room.third_party_invite event for creating a room.
Aliased Type
struct InitialRoomThirdPartyInviteEvent {
pub content: RoomThirdPartyInviteEventContent,
pub state_key: String,
}Fields
content: RoomThirdPartyInviteEventContentData specific to the event type.
state_key: StringA unique key which defines the overwriting semantics for this piece of room state.
This is often an empty string, but some events send a UserId to show which user the event
affects.
Defaults to the empty string.